==> jc-1.4.0.tar.gz: javax/swing/event/HyperlinkEvent.h <==
// public class javax.swing.event.HyperlinkEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 55d3f70b86958d84 javax_swing_event_HyperlinkEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_HyperlinkEvent_H_
#define _JC_javax_swing_event_HyperlinkEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_event_HyperlinkEvent$sub_refs	_jc_javax_swing_event_HyperlinkEvent$sub_refs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs	_jc_javax_swing_event_HyperlinkEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$refs	_jc_javax_swing_event_HyperlinkEvent$refs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$nonrefs	_jc_javax_swing_event_HyperlinkEvent$nonrefs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$object	_jc_javax_swing_event_HyperlinkEvent$object;

typedef struct _jc_javax_swing_event_HyperlinkEvent$fields_struct	_jc_javax_swing_event_HyperlinkEvent$fields_struct;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vmethods	_jc_javax_swing_event_HyperlinkEvent$vmethods;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vtable	_jc_javax_swing_event_HyperlinkEvent$vtable;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vtype	_jc_javax_swing_event_HyperlinkEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_HyperlinkEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_event_HyperlinkEvent$fields_struct _jc_javax_swing_event_HyperlinkEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$d1da3a56c3d2864f(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *);
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$60a1255af4577433(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$6808d422ba65e44e(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_HyperlinkEvent$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
extern struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *_jc_javax_swing_event_HyperlinkEvent$method$getEventType$69b71e4fb02a7a91(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
extern struct _jc_object *_jc_javax_swing_event_HyperlinkEvent$method$getSourceElement$06e806aea0d26e93(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
extern struct _jc_java_net_URL$object *_jc_javax_swing_event_HyperlinkEvent$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getDescription$2661fc1f3e986b4b;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getEventType$69b71e4fb02a7a91;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getSourceElement$06e806aea0d26e93;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_javax_swing_event_HyperlinkEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
	struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object	*(*getEventType$69b71e4fb02a7a91)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
	struct _jc_object	*(*getSourceElement$06e806aea0d26e93)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_HyperlinkEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_HyperlinkEvent$vmethods	javax_swing_event_HyperlinkEvent;
};

// Vtype
struct _jc_javax_swing_event_HyperlinkEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_HyperlinkEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_HyperlinkEvent$sub_refs {
	struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object	*type;
	struct _jc_java_net_URL$object	*url;
	struct _jc_java_lang_String$object	*description;
	struct _jc_object	*element;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_HyperlinkEvent$refs {
    _jc_javax_swing_event_HyperlinkEvent$sub_refs	javax_swing_event_HyperlinkEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_HyperlinkEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs	javax_swing_event_HyperlinkEvent;
};

// Object instance structure
struct _jc_javax_swing_event_HyperlinkEvent$object {
	_jc_javax_swing_event_HyperlinkEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_HyperlinkEvent$vtype	*vtype;
	_jc_javax_swing_event_HyperlinkEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_HyperlinkEvent$vtype _jc_javax_swing_event_HyperlinkEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_HyperlinkEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_HyperlinkEvent$class_object;

#endif	/* _JC_javax_swing_event_HyperlinkEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/HyperlinkEvent.h <==
// public class javax.swing.event.HyperlinkEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 55d3f70b86958d84 javax_swing_event_HyperlinkEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_HyperlinkEvent_H_
#define _JC_javax_swing_event_HyperlinkEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_event_HyperlinkEvent$sub_refs	_jc_javax_swing_event_HyperlinkEvent$sub_refs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs	_jc_javax_swing_event_HyperlinkEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$refs	_jc_javax_swing_event_HyperlinkEvent$refs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$nonrefs	_jc_javax_swing_event_HyperlinkEvent$nonrefs;
typedef struct _jc_javax_swing_event_HyperlinkEvent$object	_jc_javax_swing_event_HyperlinkEvent$object;

typedef struct _jc_javax_swing_event_HyperlinkEvent$fields_struct	_jc_javax_swing_event_HyperlinkEvent$fields_struct;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vmethods	_jc_javax_swing_event_HyperlinkEvent$vmethods;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vtable	_jc_javax_swing_event_HyperlinkEvent$vtable;
typedef const struct _jc_javax_swing_event_HyperlinkEvent$vtype	_jc_javax_swing_event_HyperlinkEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_HyperlinkEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_event_HyperlinkEvent$fields_struct _jc_javax_swing_event_HyperlinkEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$d1da3a56c3d2864f(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$60a1255af4577433(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_HyperlinkEvent$method$_init$6808d422ba65e44e(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_HyperlinkEvent$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object *_jc_javax_swing_event_HyperlinkEvent$method$getEventType$69b71e4fb02a7a91(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_event_HyperlinkEvent$method$getSourceElement$06e806aea0d26e93(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_javax_swing_event_HyperlinkEvent$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getDescription$2661fc1f3e986b4b;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getEventType$69b71e4fb02a7a91;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getSourceElement$06e806aea0d26e93;
extern _jc_method _jc_javax_swing_event_HyperlinkEvent$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_javax_swing_event_HyperlinkEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object	*(*getEventType$69b71e4fb02a7a91)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSourceElement$06e806aea0d26e93)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_javax_swing_event_HyperlinkEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_HyperlinkEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_HyperlinkEvent$vmethods	javax_swing_event_HyperlinkEvent;
};

// Vtype
struct _jc_javax_swing_event_HyperlinkEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_HyperlinkEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_HyperlinkEvent$sub_refs {
	struct _jc_javax_swing_event_HyperlinkEvent__24EventType$object	*type;
	struct _jc_java_net_URL$object	*url;
	struct _jc_java_lang_String$object	*description;
	struct _jc_object	*element;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_HyperlinkEvent$refs {
    _jc_javax_swing_event_HyperlinkEvent$sub_refs	javax_swing_event_HyperlinkEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_HyperlinkEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_HyperlinkEvent$sub_nonrefs	javax_swing_event_HyperlinkEvent;
};

// Object instance structure
struct _jc_javax_swing_event_HyperlinkEvent$object {
	_jc_javax_swing_event_HyperlinkEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_HyperlinkEvent$vtype	*vtype;
	_jc_javax_swing_event_HyperlinkEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_HyperlinkEvent$vtype _jc_javax_swing_event_HyperlinkEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_HyperlinkEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_HyperlinkEvent$class_object;

#endif	/* _JC_javax_swing_event_HyperlinkEvent_H_ */
